window.Gleam.initSearch([{"doc":"given","title":"given","content":"# 👇Given for Gleam\n\n[![Package &lt;a href=&quot;https://github.com/inoas/gleam-given/releases&quot;&gt;&lt;img src=&quot;https://img.shields.io/github/release/inoas/gleam-given&quot; alt=&quot;GitHub release&quot;&gt;&lt;/a&gt; Version](https://img.shields.io/hexpm/v/given)](https://hex.pm/packages/given)\n[![Erlang-compatible](https://img.shields.io/badge/target-erlang-b83998)](https://www.erlang.org/)\n[![JavaScript Compatible](https://img.shields.io/badge/target-javascript-f3e155)](https://en.wikipedia.org/wiki/JavaScript)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/given/)\n[![Discord](https://img.shields.io/discord/768594524158427167?label=discord%20chat&amp;amp;color=5865F2)](https://discord.gg/Fm8Pwmy)\n[![CI Test](https://github.com/inoas/gleam-given/actions/workflows/test.yml/badge.svg?branch=main&amp;amp;event=push)](https://github.com/inoas/gleam-given/actions/workflows/test.yml)\n\n&lt;br&gt;\n&lt;br&gt;\n\n&lt;p align=&quot;center&quot;&gt;\n  &lt;img src=&quot;https://raw.githubusercontent.com/inoas/gleam-given/main/given-logo.png&quot; alt=&quot;Given Logo&quot; style=&quot;max-height: 33vh; width: auto; height: auto&quot; width=&quot;480&quot; height=&quot;480&quot;/&gt;\n&lt;/p&gt;\n\n&lt;br&gt;\n\n&lt;p align=&quot;center&quot;&gt;\n  &lt;i&gt;\n    👇Given is a library written in Gleam to make it safe and easy to early return.\n  &lt;/i&gt;\n&lt;/p&gt;\n\n&lt;br&gt;\n&lt;br&gt;\n\n## Installation\n\n```sh\ngleam add given\n```\n\n## Usage\n\n```gleam\nimport given\n\npub fn given_that_example() {\n  let user_understood = True\n\n  use &lt;- given.that(user_understood, return: fn() { &quot;💡 Bright!&quot; })\n  // …else handle case where user did not understand here…\n  &quot;🤯 Woof!&quot;\n}\n\npub fn given_not_example() {\n  // Fetch this from some database\n  let has_admin_role = True\n\n  use &lt;- given.not(has_admin_role, return: fn() { &quot;✋ Denied!&quot; })\n  // …else handle case where they are admin here…\n  &quot;👌 Access granted...&quot;\n}\n\npub fn given_any_example() {\n  let is_admin = False\n  let is_editor = True\n\n  use &lt;- given.any([is_admin, is_editor], return: fn() {\n    &quot;At least admin or editor&quot;\n  })\n\n  // …else handle case where user has no special role…\n  &quot;Got nothing to say 🤷‍♂️&quot;\n}\n\npub fn given_all_example() {\n  let is_active = True\n  let is_confirmed = False\n\n  use &lt;- given.all([is_active, is_confirmed], return: fn() {\n    &quot;Ready, steady, go!&quot;\n  })\n\n  // …else handle case where user is not both active and confirmed…\n  &quot;Not both active and confirmed&quot;\n}\n\npub fn given_not_any_example() {\n  let is_admin = False\n  let is_editor = True\n\n  use &lt;- given.not_any([is_admin, is_editor], return: fn() {\n    &quot;At least either Admin or Editor!&quot;\n  })\n\n  // …else handle case where user no special role…\n  &quot;User has no special role!&quot;\n}\n\npub fn given_not_all_example() {\n  let is_human = False\n  let is_robot = False\n\n  use &lt;- given.not_all([is_human, is_robot], return: fn() {\n    &quot;Obsolete model detected.&quot;\n  })\n\n  // …else handle case where user is neither active nor confirmed…\n  &quot;I am a Cylon!&quot;\n}\n\npub fn given_when_example() {\n  let enabled = fn() { True }\n\n  use &lt;- given.when(enabled, else_return: fn() { &quot;Not an Admin&quot; })\n\n  // …handle case where user is an Admin…\n  &quot;Indeed an Admin&quot;\n}\n\npub fn given_when_not_example() {\n  let enabled = fn() { False }\n\n  use &lt;- given.when_not(enabled, else_return: fn() { &quot;Indeed an Admin&quot; })\n\n  // …handle case where user is not an Admin…\n  &quot;Not an Admin&quot;\n}\n\npub fn given_empty_example() {\n  let list = []\n\n  use &lt;- given.empty(list, return: fn() { &quot;Empty!&quot; })\n\n  // …handle case where user is non-empty…\n  &quot;Non-empty!&quot;\n}\n\npub fn given_non_empty_example() {\n  let list = [1]\n\n  use &lt;- given.non_empty(list, return: fn() { &quot;Non-empty!&quot; })\n\n  // …handle case where user is empty…\n  &quot;Empty!&quot;\n}\n\npub fn given_ok_example() {\n  let a_result = Ok(&quot;Hello Joe, again!&quot;)\n\n  use ok_value &lt;- given.ok(in: a_result, else_return: fn(_error_value) {\n    &quot;Error value&quot;\n  })\n  // …handle Ok value here…\n  ok_value\n}\n\npub fn given_any_ok_example() {\n  let results = [Ok(&quot;Great&quot;), Error(&quot;Bad&quot;)]\n\n  use _oks, _errors &lt;- given.any_ok(in: results, else_return: fn(_errors) {\n    &quot;All Errors&quot;\n  })\n\n  // …handle at least some OKs here…\n  &quot;At least some OKs&quot;\n}\n\npub fn given_all_ok_example() {\n  let results = [Ok(&quot;Great&quot;), Error(&quot;Bad&quot;)]\n\n  use _oks &lt;- given.all_ok(in: results, else_return: fn(_oks, _errors) {\n    &quot;Some Errors&quot;\n  })\n\n  // …handle all OKs here…\n  &quot;All OKs&quot;\n}\n\npub fn given_error_example() {\n  let a_result = Error(&quot;Memory exhausted, again!&quot;)\n\n  use error_value &lt;- given.error(in: a_result, else_return: fn(_ok_value) {\n    &quot;Ok value&quot;\n  })\n  // …handle Error value here…\n  error_value\n}\n\npub fn given_any_error_example() {\n  let results = [Ok(&quot;Good&quot;), Error(&quot;Bad&quot;)]\n\n  use _oks, _errors &lt;- given.any_error(in: results, else_return: fn(_oks) {\n    &quot;Bad&quot;\n  })\n\n  // …handle at least some Errors here…\n  &quot;Good&quot;\n}\n\npub fn given_all_error_example() {\n  {\n    let results = [Ok(&quot;Nice&quot;), Error(&quot;Meh&quot;)]\n\n    use _errors &lt;- given.all_error(in: results, else_return: fn(_oks, _errors) {\n      &quot;Meh&quot;\n    })\n\n    // …handle all errors here…\n    &quot;Nice&quot;\n  }\n}\n\nimport gleam/option.{None, Some}\n\npub fn given_some_example() {\n  let an_option = Some(&quot;One More Penny&quot;)\n\n  use some_value &lt;- given.some(in: an_option, else_return: fn() { &quot;Woof!&quot; })\n  // …handle Some value here…\n  some_value\n}\n\npub fn given_any_some_example() {\n  let options = [Some(&quot;One&quot;), None]\n\n  use _somes, _nones_count &lt;- given.any_some(\n    in: options,\n    else_return: fn(_nones_count) { &quot;Just rocks here, move on...&quot; },\n  )\n\n  // …handle at least some None values here…\n  &quot;We found some Gold!&quot;\n}\n\npub fn given_all_some_example() {\n  let options = [Some(&quot;One&quot;), None]\n\n  use _somes &lt;- given.all_some(\n    in: options,\n    else_return: fn(_somes, _nones_count) { &quot;Nothing found...&quot; },\n  )\n\n  // …handle all Some values here…\n  &quot;There is Gold everywhere!&quot;\n}\n\npub fn given_none_example() {\n  let an_option = None\n\n  use &lt;- given.none(in: an_option, else_return: fn(_some_value) { &quot;Some value&quot; })\n  // …handle None here…\n  &quot;None, e.g. Still nothing!&quot;\n}\n\npub fn given_any_none_example() {\n  let options = [Some(&quot;One&quot;), None]\n\n  use _somes, _none_count &lt;- given.any_none(\n    in: options,\n    else_return: fn(_somes) { &quot;Only Nones Here!&quot; },\n  )\n\n  // …handle at least some None values here…\n  &quot;The system detected Some-things.&quot;\n}\n\npub fn given_all_none_example() {\n  let options = [Some(&quot;One&quot;), None]\n\n  use &lt;- given.all_none(in: options, else_return: fn(_somes, _nones_count) {\n    &quot;There is something out there...&quot;\n  })\n\n  // …handle all None values here…\n  &quot;There is nothing out there...&quot;\n}\n\nimport gleam/io\n\npub fn main() {\n  given_that_example() |&gt; io.debug\n  // &quot;💡 Bright!&quot;\n\n  given_any_example() |&gt; io.debug\n  // &quot;At least admin or editor&quot;\n\n  given_all_example() |&gt; io.debug\n  // &quot;Not both active and confirmed&quot;\n\n  given_not_example() |&gt; io.debug\n  // &quot;👌 Access granted...&quot;\n\n  given_not_any_example() |&gt; io.debug\n  // &quot;User has no special role!&quot;\n\n  given_not_all_example() |&gt; io.debug\n  // &quot;Obsolete model detected.&quot;\n\n  given_when_example() |&gt; io.debug\n  // &quot;Indeed an Admin&quot;\n\n  given_when_not_example() |&gt; io.debug\n  // &quot;Not an Admin&quot;\n\n  given_empty_example() |&gt; io.debug\n  // &quot;Empty!&quot;\n\n  given_non_empty_example() |&gt; io.debug\n  // &quot;Non-empty!&quot;\n\n  given_ok_example() |&gt; io.debug\n  // &quot;Hello Joe, again!&quot;\n\n  given_any_ok_example() |&gt; io.debug\n  // &quot;At least some OKs&quot;\n\n  given_all_ok_example() |&gt; io.debug\n  // &quot;Some Errors&quot;\n\n  given_error_example() |&gt; io.debug\n  // &quot;Memory exhausted, again!&quot;\n\n  given_any_error_example() |&gt; io.debug\n  // &quot;Good&quot;\n\n  given_all_error_example() |&gt; io.debug\n  // &quot;Meh&quot;\n\n  given_some_example() |&gt; io.debug\n  // &quot;One More Penny&quot;\n\n  given_any_some_example() |&gt; io.debug\n  // &quot;We found some Gold!&quot;\n\n  given_all_some_example() |&gt; io.debug\n  // &quot;Nothing found...&quot;\n\n  given_none_example() |&gt; io.debug\n  // &quot;None, e.g. Still nothing&quot;\n\n  given_any_none_example() |&gt; io.debug\n  // &quot;The system detected Some-things.&quot;\n\n  given_all_none_example() |&gt; io.debug\n  // &quot;There is something out there...&quot;\n}\n```\n\n### Run usage examples\n\n```sh\ngleam run --module given/internal/usage_examples\n```\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"given","title":"all","content":"pub fn all(\n  are_true_in requirements: List(Bool),\n  return consequence: fn() -&gt; a,\n  else_return alternative: fn() -&gt; a,\n) -&gt; a\n Checks if all of the conditions are true and runs the consequence if all\n are, else runs the alternative.\n\n ## Examples\n\n \n import given\n\n let is_active = True\n let is_confirmed = True\n\n use &lt;- given.all([is_active, is_confirmed], return: fn() { &quot;Great!&quot; })\n\n // …else handle case where user is not both active and confirmed…\n &quot;Woof!&quot;\n \n\n \n import given\n\n let is_active = True\n let is_confirmed = True\n\n use &lt;- given.all(are_true_in: [is_active, is_confirmed], return: fn() { &quot;Great!&quot; })\n\n // …else handle case where user is not both active and confirmed…\n &quot;Woof!&quot;\n \nSynonyms:\ngiven.all\ngiven all","url":"given.html#all"},{"doc":"given","title":"all_error","content":"pub fn all_error(\n  in rslts: List(Result(a, b)),\n  else_return alternative: fn(List(a), List(b)) -&gt; c,\n  return consequence: fn(List(b)) -&gt; c,\n) -&gt; c\n Checks if all of the results are `Error` and runs the consequence - passing\n in the `Error` values - if they are, else runs the alternative passing in\n all `Ok` and `Error` values.\n\n ## Examples\n\n \n import given\n\n let results = [Ok(&quot;Great&quot;), Error(&quot;Bad&quot;)]\n\n use _errors &lt;- given.all_error(in: results, else_return: fn(_oks, _errors) { &quot;Only some Errors&quot; })\n\n // …handle all errors here…\n &quot;All Errors&quot;\n \n\nSynonyms:\ngiven.all_error\ngiven all_error","url":"given.html#all_error"},{"doc":"given","title":"all_none","content":"pub fn all_none(\n  in optns: List(Option(a)),\n  else_return alternative: fn(List(a), Int) -&gt; b,\n  return consequence: fn() -&gt; b,\n) -&gt; b\n Checks if all of the options are `None` and runs the consequence if they\n are, else runs the alternative passing in the `Some` values.\n\n ## Examples\n\n \n import given\n\n let options = [Some(&quot;One&quot;), None]\n\n use &lt;- given.all_none(in: options, else_return: fn(_somes, _nones_count) { &quot;Some are Some&quot; })\n\n // …handle all None values here…\n &quot;All are None&quot;\n \n\nSynonyms:\ngiven.all_none\ngiven all_none","url":"given.html#all_none"},{"doc":"given","title":"all_ok","content":"pub fn all_ok(\n  in rslts: List(Result(a, b)),\n  else_return alternative: fn(List(a), List(b)) -&gt; c,\n  return consequence: fn(List(a)) -&gt; c,\n) -&gt; c\n Checks if all of the results are `Ok` and runs the consequence - passing in\n the `Ok` values - if they are, else runs the alternative passing in all\n `Ok` and `Error` values.\n\n ## Examples\n\n \n import given\n\n let results = [Ok(&quot;Great&quot;), Error(&quot;Bad&quot;)]\n\n use oks &lt;- given.all_ok(in: results, else_return: fn(_oks, _errors) { &quot;Some Errors&quot; })\n\n // …handle all OKs here…\n &quot;All OKs&quot;\n \n\nSynonyms:\ngiven.all_ok\ngiven all_ok","url":"given.html#all_ok"},{"doc":"given","title":"all_some","content":"pub fn all_some(\n  in optns: List(Option(a)),\n  else_return alternative: fn(List(a), Int) -&gt; b,\n  return consequence: fn(List(a)) -&gt; b,\n) -&gt; b\n Checks if all of the options are `Some` and runs the consequence - passing\n in the `Some` values - if they are, else runs the alternative passing in\n the `Some` and a count of the `None` values.\n\n ## Examples\n\n \n import given\n\n let options = [Some(&quot;One&quot;), None]\n\n use _somes &lt;- given.all_some(in: options, else_return: fn(_somes, _nones_count) { &quot;Some are None&quot; })\n\n // …handle all Some values here…\n &quot;All are Some&quot;\n \n\nSynonyms:\ngiven.all_some\ngiven all_some","url":"given.html#all_some"},{"doc":"given","title":"any","content":"pub fn any(\n  are_true_in requirements: List(Bool),\n  return consequence: fn() -&gt; a,\n  else_return alternative: fn() -&gt; a,\n) -&gt; a\n Checks if any of the conditions are true and runs the consequence if any\n are, else runs the alternative.\n\n ## Examples\n\n \n import given\n\n let is_admin = False\n let is_editor = True\n\n use &lt;- given.any([is_admin, is_editor], return: fn() { &quot;Great!&quot; })\n\n // …else handle case where user has no special role…\n &quot;Woof!&quot;\n \n\n \n import given\n\n let is_admin = False\n let is_editor = True\n\n use &lt;- given.any(are_true_in: [is_admin, is_editor], return: fn() { &quot;Great!&quot; })\n\n // …else handle case where user has no special role…\n &quot;Woof!&quot;\n \n\nSynonyms:\ngiven.any\ngiven any","url":"given.html#any"},{"doc":"given","title":"any_error","content":"pub fn any_error(\n  in rslts: List(Result(a, b)),\n  else_return alternative: fn(List(a)) -&gt; c,\n  return consequence: fn(List(a), List(b)) -&gt; c,\n) -&gt; c\n Checks if any of the results are `Error` and runs the consequence - passing\n in the `Ok` and `Error` values - if they are, else runs the alternative\n passing in all `Ok` values.\n\n ## Examples\n\n \n import given\n\n let results = [Ok(&quot;Great&quot;), Error(&quot;Bad&quot;)]\n\n use _oks, _errors &lt;- given.any_error(in: results, else_return: fn(_oks) { &quot;Only OKs&quot; })\n\n // …handle at least some Errors here…\n &quot;At least some Errors&quot;\n \n\nSynonyms:\ngiven.any_error\ngiven any_error","url":"given.html#any_error"},{"doc":"given","title":"any_none","content":"pub fn any_none(\n  in optns: List(Option(a)),\n  else_return alternative: fn(List(a)) -&gt; b,\n  return consequence: fn(List(a), Int) -&gt; b,\n) -&gt; b\n Checks if any of the options are `None` and runs the consequence if they\n are, else runs the alternative passing in the `Some` values and the count\n of `None` values.\n\n ## Examples\n\n \n import given\n\n let options = [Some(&quot;One&quot;), None]\n\n use &lt;- given.any_none(in: options, else_return: fn(_somes) { &quot;All are Some&quot; })\n\n // …handle at least some None values here…\n &quot;At least some are None&quot;\n \n\nSynonyms:\ngiven.any_none\ngiven any_none","url":"given.html#any_none"},{"doc":"given","title":"any_ok","content":"pub fn any_ok(\n  in rslts: List(Result(a, b)),\n  else_return alternative: fn(List(b)) -&gt; c,\n  return consequence: fn(List(a), List(b)) -&gt; c,\n) -&gt; c\n Checks if any of the results are `Ok` and runs the consequence -  passing in\n the `Ok` and `Error` values - if they are, else runs the alternative passing\n in all `Error` values.\n\n ## Examples\n\n \n import given\n\n let results = [Ok(&quot;Great&quot;), Error(&quot;Bad&quot;)]\n\n use _oks, _errors &lt;- given.any_ok(in: results, else_return: fn(_errors) { &quot;All Errors&quot; })\n\n // …handle at least some OKs here…\n &quot;At least some OKs&quot;\n \n\nSynonyms:\ngiven.any_ok\ngiven any_ok","url":"given.html#any_ok"},{"doc":"given","title":"any_some","content":"pub fn any_some(\n  in optns: List(Option(a)),\n  else_return alternative: fn(Int) -&gt; b,\n  return consequence: fn(List(a), Int) -&gt; b,\n) -&gt; b\n Checks if any of the options are `Some` and runs the consequence - passing\n in the `Some` values and a count of the `None` values - if they are, else\n runs the alternative passing in the count of `None` values.\n\n ## Examples\n\n \n import given\n\n let options = [Some(&quot;One&quot;), None]\n\n use _somes, _nones_count &lt;- given.any_some(in: options, else_return: fn(_nones_count) { &quot;All are None&quot; })\n\n // …handle at least some None values here…\n &quot;At least some are None&quot;\n \n\nSynonyms:\ngiven.any_some\ngiven any_some","url":"given.html#any_some"},{"doc":"given","title":"empty","content":"pub fn empty(\n  list list: List(a),\n  else_return alternative: fn() -&gt; b,\n  return consequence: fn() -&gt; b,\n) -&gt; b\n Checks if the list is empty and runs the consequence if it is, else runs\n the alternative.\n\n ## Examples\n\n \n import given\n\n let list = []\n\n use &lt;- given.empty(list, else_return: fn() { &quot;Non-empty&quot; })\n\n // …handle empty list here…\n &quot;Empty&quot;\n \n\nSynonyms:\ngiven.empty\ngiven empty","url":"given.html#empty"},{"doc":"given","title":"error","content":"pub fn error(\n  in rslt: Result(a, b),\n  else_return alternative: fn(a) -&gt; c,\n  return consequence: fn(b) -&gt; c,\n) -&gt; c\n Checks if the result is an `Error` and runs the consequence if it is, else\n runs the alternative.\n\n ## Examples\n\n \n import given\n\n let result = Error(Nil)\n\n use error_value &lt;- given.error(in: result, else_return: fn(ok_value) { &quot;Ok&quot; })\n\n // …handle Error value here…\n &quot;Error&quot;\n \n\n \n import given.{error as given_error_in}\n\n let result = Error(Nil)\n\n use error_value &lt;- given_error_in(result, else_return: fn(ok_value) { &quot;Ok&quot; })\n\n // …handle Error value here…\n &quot;Error&quot;\n \n\nSynonyms:\ngiven.error\ngiven error","url":"given.html#error"},{"doc":"given","title":"non_empty","content":"pub fn non_empty(\n  list list: List(a),\n  else_return alternative: fn() -&gt; b,\n  return consequence: fn() -&gt; b,\n) -&gt; b\n Checks if the list is non-empty and runs the consequence if it is, else\n runs the alternative.\n\n ## Examples\n\n \n import given\n\n let list = []\n\n use &lt;- given.non_empty(list, else_return: fn() { &quot;Empty&quot; })\n\n // …handle non-empty list here…\n &quot;Non-empty&quot;\n \n\nSynonyms:\ngiven.non_empty\ngiven non_empty","url":"given.html#non_empty"},{"doc":"given","title":"none","content":"pub fn none(\n  in optn: Option(a),\n  else_return alternative: fn(a) -&gt; b,\n  return consequence: fn() -&gt; b,\n) -&gt; b\n Checks if the option is `None` and runs the consequence if it is, else runs\n the alternative.\n\n ## Examples\n\n \n import given\n import gleam/option.{None}\n\n let option = None\n\n use &lt;- given.none(in: option, else_return: fn(some_value) { &quot;Some value&quot; })\n\n // …handle None here…\n &quot;None&quot;\n \n\n \n import given.{none as given_none_in}\n import gleam/option.{None}\n\n let option = None\n\n use &lt;- given_none_in(option, else_return: fn(some_value) { &quot;Some value&quot; })\n // …handle None here…\n\n &quot;None&quot;\n \n\nSynonyms:\ngiven.none\ngiven none","url":"given.html#none"},{"doc":"given","title":"not","content":"pub fn not(\n  the_case requirement: Bool,\n  return consequence: fn() -&gt; a,\n  else_return alternative: fn() -&gt; a,\n) -&gt; a\n Checks if the condition is false and runs the consequence if it is, else\n runs the alternative.\n\n ## Examples\n\n \n import given\n\n let user_understood = True\n\n use &lt;- given.not(user_understood, return: fn() { &quot;Woof!&quot; })\n\n // …else handle case where user understood here…\n &quot;Great!&quot;\n \n\n \n import given\n\n let user_understood = True\n\n use &lt;- given.not(the_case: user_understood, return: fn() { &quot;Woof!&quot; })\n\n // …else handle case where user understood here…\n &quot;Great!&quot;\n \n\n \n import given.{not as not_given}\n\n let user_understood = True\n\n use &lt;- not_given(user_understood, return: fn() { &quot;Woof!&quot; })\n\n // …else handle case where user understood here…\n &quot;Great!&quot;\n \n\nSynonyms:\ngiven.not\ngiven not","url":"given.html#not"},{"doc":"given","title":"not_all","content":"pub fn not_all(\n  are_true_in requirements: List(Bool),\n  return consequence: fn() -&gt; a,\n  else_return alternative: fn() -&gt; a,\n) -&gt; a\n Checks if all of the conditions are false and runs the consequence if all\n are, else runs the alternative.\n\n ## Examples\n\n \n import given\n\n let is_active = True\n let is_confirmed = True\n\n use &lt;- given.not_all([is_active, is_confirmed], return: fn() { &quot;Cylone Sleeper Agent!&quot; })\n\n // …else handle case where user is neither active nor confirmed…\n &quot;Woof!&quot;\n \n\n \n import given\n\n let is_active = True\n let is_confirmed = True\n\n use &lt;- given.not_all(are_true_in: [is_active, is_confirmed], return: fn() { &quot;Cylone Sleeper Agent!&quot; })\n\n // …else handle case where user is neither active nor confirmed…\n &quot;Woof!&quot;\n\nSynonyms:\ngiven.not_all\ngiven not_all","url":"given.html#not_all"},{"doc":"given","title":"not_any","content":"pub fn not_any(\n  are_true_in requirements: List(Bool),\n  return consequence: fn() -&gt; a,\n  else_return alternative: fn() -&gt; a,\n) -&gt; a\n Checks if any of the conditions are false and runs the consequence if any\n are, else runs the alternative.\n\n ## Examples\n\n \n import given\n\n let is_admin = False\n let is_editor = True\n\n use &lt;- given.not_any([is_admin, is_editor], return: fn() { &quot;At least either Admin or Editor!&quot; })\n\n // …else handle case where user no special role…\n &quot;Woof!&quot;\n \n\n \n import given\n\n let is_admin = False\n let is_editor = True\n\n use &lt;- given.not_any(are_true_in: [is_admin, is_editor], return: fn() { &quot;At least either Admin or Editor!&quot; })\n\n // …else handle case where user no special role…\n &quot;Woof!&quot;\n \n\nSynonyms:\ngiven.not_any\ngiven not_any","url":"given.html#not_any"},{"doc":"given","title":"ok","content":"pub fn ok(\n  in rslt: Result(a, b),\n  else_return alternative: fn(b) -&gt; c,\n  return consequence: fn(a) -&gt; c,\n) -&gt; c\n Checks if the result is an `Ok` and runs the consequence if it is, else\n runs the alternative.\n\n ## Examples\n\n \n import given\n\n let result = Ok(&quot;Great&quot;)\n\n use ok_value &lt;- given.ok(in: result, else_return: fn(error_value) { &quot;Error&quot; })\n\n // …handle Ok value here…\n &quot;Ok&quot;\n \n\n \n import given.{ok as given_ok_in}\n\n let result = Ok(&quot;Great&quot;)\n\n use ok_value &lt;- given_ok_in(result, else_return: fn(error_value) { &quot;Error&quot; })\n\n // …handle Ok value here…\n &quot;Ok&quot;\n \n\nSynonyms:\ngiven.ok\ngiven ok","url":"given.html#ok"},{"doc":"given","title":"some","content":"pub fn some(\n  in optn: Option(a),\n  else_return alternative: fn() -&gt; b,\n  return consequence: fn(a) -&gt; b,\n) -&gt; b\n Checks if the option is `Some` and runs the consequence if it is, else runs\n the alternative.\n\n ## Examples\n\n \n import given\n import gleam/option.{Some}\n\n let option = Some(&quot;One&quot;)\n\n use some_value &lt;- given.some(in: option, else_return: fn() { &quot;None&quot; })\n\n // …handle Some value here…\n &quot;Some value&quot;\n \n\n \n import given.{some as given_some_in}\n import gleam/option.{Some}\n\n let option = Some(&quot;One&quot;)\n\n use some_value &lt;- given_some_in(option, else_return: fn() { &quot;None&quot; })\n\n // …handle Some value here…\n &quot;Some value&quot;\n \n\nSynonyms:\ngiven.some\ngiven some","url":"given.html#some"},{"doc":"given","title":"that","content":"pub fn that(\n  the_case requirement: Bool,\n  return consequence: fn() -&gt; a,\n  else_return alternative: fn() -&gt; a,\n) -&gt; a\n Checks if the condition is true and runs the consequence if it is, else\n runs the alternative.\n\n ## Examples\n\n \n import given\n\n let user_understood = True\n\n use &lt;- given.that(user_understood, return: fn() { &quot;Great!&quot; })\n // …else handle case where user did not understand here…\n &quot;Woof!&quot;\n \n\n \n import given.{that as given}\n\n let user_understood = True\n\n use &lt;- given(user_understood, return: fn() { &quot;Great!&quot; })\n // …else handle case where user did not understand here…\n &quot;Woof!&quot;\n \n\nSynonyms:\ngiven.that\ngiven that","url":"given.html#that"},{"doc":"given","title":"when","content":"pub fn when(\n  the_case condition: fn() -&gt; Bool,\n  else_return alternative: fn() -&gt; a,\n  return consequence: fn() -&gt; a,\n) -&gt; a\n Checks if the condition function returns `True` and runs the consequence if\n it is, else runs the alternative.\n\n Use to lazily evaluate a complex condition and return early if they fail.\n\n ## Examples\n\n \n import given\n\n let enabled = fn() { False }\n\n use &lt;- given.when(enabled, else_return: fn() { &quot;Not an Admin&quot; })\n\n // …handle case where user is an Admin…\n &quot;Indeed an Admin&quot;\n \n\n \n import given\n\n let enabled = fn() { False }\n\n use &lt;- given.when(enabled, return: fn() { &quot;Indeed an Admin&quot; })\n\n // …handle case where user is not an Admin…\n &quot;Not an Admin&quot;\n \n\nSynonyms:\ngiven.when\ngiven when","url":"given.html#when"},{"doc":"given","title":"when_not","content":"pub fn when_not(\n  the_case condition: fn() -&gt; Bool,\n  else_return alternative: fn() -&gt; a,\n  return consequence: fn() -&gt; a,\n) -&gt; a\n Checks if the condition function returns `False` and runs the consequence if\n it is, else runs the alternative.\n\n Use to lazily evaluate a complex condition and return early if they fail.\n\n ## Examples\n\n \n import given\n\n let enabled = fn() { False }\n\n use &lt;- given.when_not(enabled, else_return: fn() { &quot;Indeed an Admin&quot; })\n\n // …handle case where user is not an Admin…\n &quot;Not an Admin&quot;\n \n\n \n import given\n\n let enabled = fn() { False }\n\n use &lt;- given.when_not(enabled, return: fn() { &quot;Not an Admin&quot; })\n\n // …handle case where user is an Admin…\n &quot;Indeed an Admin&quot;\n \n\nSynonyms:\ngiven.when_not\ngiven when_not","url":"given.html#when_not"},{"doc":"given","title":"given","content":" This library attempts to make guards:\n\n - Applicable to `Bool`, `Result`, `Option` and `List` types.\n - Ergonomic to use by providing ways to handle both branches early.\n - Expressive by making it easy to read through function names and labels.\n - Comprehendable by not having to negate the conditions.\n - Safe to use by not accidentally running discarded branches much like\n   `bool.lazy_guard`.\n","url":"given.html"}]);